datablock AudioProfile(LonglasFireSound)
{
   filename    = "./longlas_shot.wav";
   description = AudioClose3d;
   preload = true;
};

datablock ProjectileData(RED_LongLasExplosionProjectile)
{
   directDamage        = 0;
   directDamageType    = $DamageType::Gun;
   radiusDamageType    = $DamageType::Gun;

   brickExplosionRadius = 0;
   brickExplosionImpact = true;          //destroy a brick if we hit it directly?
   brickExplosionForce  = 10;
   brickExplosionMaxVolume = 1;          //max volume of bricks that we can destroy
   brickExplosionMaxVolumeFloating = 2;  //max volume of bricks that we can destroy if they aren't connected to the ground

   impactImpulse	     = 100;
   verticalImpulse	  = 50;
   explosion           = RED_HotShotLasgunExplosion;
   particleEmitter     = "RED_HotShotLasgunExplosionRingEmitter";

   muzzleVelocity      = 200;
   velInheritFactor    = 0;

   armingDelay         = 0;
   lifetime            = 9000;
   fadeDelay           = 8700;
   bounceElasticity    = 0.5;
   bounceFriction      = 0.10;
   isBallistic         = true;
   gravityMod = 0.0;

   hasLight    = false;
   lightRadius = 3.0;
   lightColor  = "0 0 0.5";
};

datablock ProjectileData(BLU_LongLasExplosionProjectile : RED_LongLasExplosionProjectile)
{
   explosion           = BLU_HotShotLasgunExplosion;
   particleEmitter     = "BLU_HotShotLasgunExplosionRingEmitter";
};

//////////
// item //
//////////
datablock ItemData(RED_LonglasItem)
{
	category = "Weapon";  // Mission editor category
	className = "Weapon"; // For inventory system

	 // Basic Item Properties
	shapeFile = "./Longlas.dts";
	rotate = false;
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;

	//gui stuff
	uiName = "Long-las R";
	iconName = "./Longlas";
	doColorShift = false;
	colorShiftColor = "1 0 0 1.000";

	 // Dynamic properties defined by the scripts
	image = RED_LonglasImage;
	canDrop = true;
    
   //Ammo Guns Parameters
   maxAmmo = 10;
   canReload = 1;
};

datablock ItemData(BLU_LonglasItem : RED_LonglasItem)
{
	uiName = "Long-las B";
	image = BLU_LonglasImage;
	shapeFile = "./Blu/Longlas.dts";
};

////////////////
//weapon image//
////////////////
datablock ShapeBaseImageData(RED_LonglasImage)
{
   raycastWeaponRange = 400;
   raycastWeaponTargets =
                   $TypeMasks::PlayerObjectType |    //AI/Players
                   $TypeMasks::StaticObjectType |    //Static Shapes
                   $TypeMasks::TerrainObjectType |    //Terrain
                   $TypeMasks::VehicleObjectType |    //Terrain
                   $TypeMasks::FXBrickObjectType;    //Bricks
   raycastExplosionProjectile = RED_HotShotLasgunExplosionProjectile;
   raycastTracerProjectile = RED_LongLasExplosionProjectile;
   raycastCritTracerProjectile = RED_HotShotLasgunTracerProjectile;
   raycastExplosionBrickSound = bulletHitSound;
   raycastExplosionPlayerSound = bulletHitSound;
   raycastCritDirectDamageType = $DamageType::Lasrifle;
   raycastDirectDamage = 100; //Varies
   raycastDirectDamageType = $DamageType::Lasrifle;
   raycastSpreadAmt = 0; //Varies

   // Basic Item properties
	shapeFile = "./Longlas.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";
   eyeOffset = 0; //"0.7 1.2 -0.5";
   rotation = eulerToMatrix( "0 0 0" );

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = true;

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = RED_LonglasItem;
   ammo = " ";
   projectile = gunProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = false;
   //raise your arm up or not
   armReady = true;

   minShotTime = 1450;   //minimum time allowed between shots (needed to prevent equip/dequip exploit)

   doColorShift = false;
   colorShiftColor = RED_LonglasItem.colorShiftColor;

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]                    = "Activate";
	stateTimeoutValue[0]            = 0.2;
	stateSequence[0]			  = "Activate";
	stateSound[0]			  = weaponSwitchSound;
	stateTransitionOnTimeout[0]     = "Ready";

	stateName[1]                    = "Ready";
	stateTransitionOnTriggerDown[1] = "Fire";
	stateAllowImageChange[1]        = true;
	stateSequence[1]			  = "ready";

	stateName[2]                    = "Fire";
	stateTransitionOnTimeout[2]     = "Wait2";
	stateTimeoutValue[2]            = 0.1;
	stateFire[2]                    = true;
	stateAllowImageChange[2]        = false;
	stateScript[2]                  = "onFire";
	stateWaitForTimeout[2]		  = true;
	stateEmitter[2]			  = gunFlashEmitter;
	stateEmitterTime[2]		  = 0.05;
	stateEmitterNode[2]		  = "muzzleNode";
	stateSound[2]			  = LonglasFireSound;

	stateName[3] 			  = "Smoke";
	stateEmitter[3]			  = gunSmokeEmitter;
	stateEmitterTime[3]		  = 0.1;
	stateEmitterNode[3]		  = "muzzleNode";
	stateSequence[3]			  = "eject";
	stateTimeoutValue[3]            = 0.75;
	stateTransitionOnTimeout[3]     = "Wait3";


	stateName[12] 			  = "Wait2";
	stateTimeoutValue[12]            = 0.1;
	stateTransitionOnTimeout[12]     = "Smoke";

	stateName[13] 			  = "Wait3";
	stateTimeoutValue[13]            = 0.1;
	stateTransitionOnTimeout[13]     = "Ready";
};
datablock ShapeBaseImageData(BLU_LonglasImage : RED_LonglasImage)
{
   raycastExplosionProjectile = BLU_HotShotLasgunExplosionProjectile;
   raycastTracerProjectile = BLU_LongLasExplosionProjectile;
   raycastCritTracerProjectile = BLU_HotShotLasgunTracerProjectile;

   item = BLU_LonglasItem;
   colorShiftColor = BLU_LonglasItem.colorShiftColor;
   shapeFile = "./Blu/Longlas.dts";
};

function RED_LonglasImage::onMount(%this,%obj,%slot)
{
   Parent::onMount(%this,%obj,%slot);

   %obj.lastFireTime = getSimTime() - 500;
}
function BLU_LonglasImage::onMount(%this,%obj,%slot)
{
   Parent::onMount(%this,%obj,%slot);

   %obj.lastFireTime = getSimTime() - 500;
}

function RED_LonglasImage::onFire(%this,%obj,%slot)
{
	%obj.spawnExplosion(TTBigRecoilProjectile,"1 1 1");
	if((%obj.lastFireTime+%this.minShotTime) > getSimTime())
	{
		%thread = "plant";
		%this.raycastExplosionProjectile = RED_HotShotLasgunExplosionProjectile;
		%this.raycastSpreadAmt = ((%obj.lastFireTime+%this.minShotTime) - getSimTime())/%this.minShotTime*0.005;
		%this.raycastDirectDamage = 35;
	}
	else
	{
		%thread = "plant";
		%this.raycastExplosionProjectile = RED_HotShotLasgunExplosionProjectile;
		%this.raycastSpreadAmt = 0;
		%this.raycastDirectDamage = 35;
	}
	Parent::onFire(%this,%obj,%slot);
}

function BLU_LonglasImage::onFire(%this,%obj,%slot)
{
	%obj.spawnExplosion(TTBigRecoilProjectile,"1 1 1");
	if((%obj.lastFireTime+%this.minShotTime) > getSimTime())
	{
		%thread = "plant";
		%this.raycastExplosionProjectile = BLU_HotShotLasgunExplosionProjectile;
		%this.raycastSpreadAmt = ((%obj.lastFireTime+%this.minShotTime) - getSimTime())/%this.minShotTime*0.005;
		%this.raycastDirectDamage = 35;
	}
	else
	{
		%thread = "plant";
		%this.raycastExplosionProjectile = BLU_HotShotLasgunExplosionProjectile;
		%this.raycastSpreadAmt = 0;
		%this.raycastDirectDamage = 35;
	}
	Parent::onFire(%this,%obj,%slot);
}

	

function RED_LonglasImage::isRaycastCritical(%this, %obj, %slot, %col, %pos, %normal, %hit)
{
   if(%this.raycastSpreadAmt > 0)
      return 0;
   if(!isObject(%col))
      return 0;
   if(isObject(%col.spawnBrick) && %col.spawnBrick.getGroup().client == %obj.client)
      %dmg = 1;
   if(miniGameCanDamage(%obj,%col) != 1 && !%dmg)
      return 0;
   if(%col.getType() & $TypeMasks::PlayerObjectType)
   {
      %colscale = getWord(%col.getScale(),2);
      return(getword(%pos, 2) > getword(%col.getWorldBoxCenter(), 2) - 3.3*%colscale);
      //return (getWord(%col.getDamageLocation(%pos),0) $= "head");
   }
   return 0;
}

function BLU_LonglasImage::isRaycastCritical(%this, %obj, %slot, %col, %pos, %normal, %hit)
{
   if(%this.raycastSpreadAmt > 0)
      return 0;
   if(!isObject(%col))
      return 0;
   if(isObject(%col.spawnBrick) && %col.spawnBrick.getGroup().client == %obj.client)
      %dmg = 1;
   if(miniGameCanDamage(%obj,%col) != 1 && !%dmg)
      return 0;
   if(%col.getType() & $TypeMasks::PlayerObjectType)
   {
      %colscale = getWord(%col.getScale(),2);
      return(getword(%pos, 2) > getword(%col.getWorldBoxCenter(), 2) - 3.3*%colscale);
      //return (getWord(%col.getDamageLocation(%pos),0) $= "head");
   }
   return 0;
}
